"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const DybamoDbService_1 = require("../AWS/DynamoDb/DybamoDbService");
const Environment = require("../Utils/Environment");
const EnvironmentNotSetError_1 = require("../Models/Exceptions/EnvironmentNotSetError");
const ResponseBase_1 = require("../Models/ResponseBase");
const QueryKeys_1 = require("../AWS/Models/QueryKeys");
/**
 * Base class for all controllers
 */
class ControllerBase {
    getDynamoDbService(table, index = '', sortAscending = false) {
        // Read region and table from environment
        const region = Environment.getRegion();
        if (region === '' || table === '') {
            throw new EnvironmentNotSetError_1.default(this.getEnvrionmentVariableNotSetResponse(region, table));
        }
        // Save to dynamodb
        const dynamoDbOptions = {
            Region: region,
            TableName: table,
            IndexName: index,
            SortAscending: sortAscending,
            AccessKey: process.env.AccessKey,
            Secret: process.env.Secret
        };
        const dynamoDbService = new DybamoDbService_1.default(dynamoDbOptions);
        return dynamoDbService;
    }
    getEnvrionmentVariableNotSetResponse(region, table) {
        var errorResponse = new ResponseBase_1.default();
        errorResponse.isSuccess = false;
        errorResponse.error = `Set REGION and table environment variables. Current values are:
                           REGION: ${region}
                           table: ${table}`;
        return errorResponse;
    }
    getQueryKeys(request) {
        const queryKeys = new QueryKeys_1.default();
        const keys = Object.keys(request.pathParameters);
        keys.forEach((key) => {
            queryKeys.addKey({ key: key, value: request.pathParameters[key] });
        });
        return queryKeys;
    }
}
exports.default = ControllerBase;
//# sourceMappingURL=ControllerBase.js.map